@@ -24,7 +24,6 @@ def initialize_jvm(function):
     """
 
     def wrapper(*args, **kwargs):
-        logging.info(function.__name__)
         try:
             # Import content inside jar file
             jpype.addClassPath('ergo.jar')
@@ -37,11 +36,17 @@ def initialize_jvm(function):
 
         finally:
             # Call function
-            return function(*args, **kwargs)
+            res = function(*args, **kwargs)
+
+            return res
 
     return wrapper
 
 
+@initialize_jvm
+def exit():
+    jpype.java.lang.System.exit(0)
+
 @initialize_jvm
 def get_wallet_address(ergo: appkit.ErgoAppKit, amount: int, wallet_mnemonic: str,
                        mnemonic_password: str = None) -> str:
@@ -214,8 +219,3 @@ def create_token(ergo: appkit.ErgoAppKit, token_name: str, description: str, tok
     signed_tx = ergo.signTransaction(unsigned_tx, mnemonic[0], prover_index)
 
     return ergo.txId(signed_tx)
-
-
-@initialize_jvm
-def exit():
-    return jpype.java.lang.System.exit(0)
